package cn.minestar.agriculture.service.impl;

import cn.minestar.agriculture.entity.WxMiniAttach;
import cn.minestar.agriculture.mapper.WxMiniAttachMapper;
import cn.minestar.agriculture.service.IWxMiniAttachService;
import cn.minestar.common.config.JooLunConfig;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import java.io.File;
import java.io.IOException;
import java.util.List;

/**
 * 【请填写功能名称】Service业务层处理
 * 
 * @author www.minestar.cn/
 * @date 2021-08-10
 */
@Slf4j
@Service
public class WxMiniAttachServiceImpl implements IWxMiniAttachService
{
    @Autowired
    private WxMiniAttachMapper wxMiniAttachMapper;

    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】ID
     * @return 【请填写功能名称】
     */
    @Override
    public WxMiniAttach selectWxMiniAttachById(Long id)
    {
        return wxMiniAttachMapper.selectWxMiniAttachById(id);
    }

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param wxMiniAttach 【请填写功能名称】
     * @return 【请填写功能名称】
     */
    @Override
    public List<WxMiniAttach> selectWxMiniAttachList(WxMiniAttach wxMiniAttach)
    {
        return wxMiniAttachMapper.selectWxMiniAttachList(wxMiniAttach);
    }

    /**
     * 新增【请填写功能名称】
     * 
     * @param wxMiniAttach 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int insertWxMiniAttach(WxMiniAttach wxMiniAttach)
    {
        return wxMiniAttachMapper.insertWxMiniAttach(wxMiniAttach);
    }

    /**
     * 修改【请填写功能名称】
     * 
     * @param wxMiniAttach 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int updateWxMiniAttach(WxMiniAttach wxMiniAttach)
    {
        return wxMiniAttachMapper.updateWxMiniAttach(wxMiniAttach);
    }

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param ids 需要删除的【请填写功能名称】ID
     * @return 结果
     */
    @Override
    public int deleteWxMiniAttachByIds(Long[] ids)
    {
        return wxMiniAttachMapper.deleteWxMiniAttachByIds(ids);
    }

    /**
     * 删除【请填写功能名称】信息
     * 
     * @param id 【请填写功能名称】ID
     * @return 结果
     */
    @Override
    public int deleteWxMiniAttachById(Long id)
    {
        return wxMiniAttachMapper.deleteWxMiniAttachById(id);
    }

    @Override
    public String upload(MultipartFile file) {
        String path =  JooLunConfig.getProfile();
        String imageVisitPath = path.substring(path.lastIndexOf("wx"));
        String originalFile =  file.getOriginalFilename();
        String ext =  originalFile.substring(originalFile.lastIndexOf("."));
        String fileName = String.valueOf(System.currentTimeMillis()) + ext;
        if(!new File(path).exists()){
            new File(path).mkdirs();
        }
        try {
            file.transferTo(new File(path + fileName));
        } catch (IOException e) {
            e.printStackTrace();
            log.error( originalFile + "文件上传失败！");
        }finally {

        }
        return imageVisitPath + fileName;
    }
}
